..
    This file is part of Invenio.
    Copyright (C) 2018 CERN.

    Invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.

.. _releases:

Releases
---------
Notes on getting involved, contributing, legal information and release notes
are here for the interested.

.. toctree::
    :maxdepth: 2
    :name: mastertoc

    maintenance-policy
    v3.1.1
    v3.1.0
    v3.0.2
    v3.0.1
    v3.0.0
    v2
    v1
    v0
